(function (d3) {
    'use strict';
  
    const svg = d3.select('svg');
    const width = document.body.clientWidth;
    const height = document.body.clientHeight;
     
    const margin = { top: 0, right: 50, bottom: 0, left: 75};
    const innerWidth = width - margin.left - margin.right;
    const innerHeight = height - margin.top - margin.bottom;
     
    const nw=100;
    const nh=100;
    const treeLayout = d3.tree()
    .nodeSize([nw,nh])
    .separation(function(a, b) { return (a.parent == b.parent ? 1 : 2)  })
    .size([innerHeight, innerWidth]);
                                                                                                                                                    ;
     
    const zoomG = svg
        .attr('width', width)
        .attr('height', height)
      .append('g');
     
    const g = zoomG.append('g')
        .attr('transform', `translate(${margin.left},${margin.top})`);
     
    svg.call(d3.zoom().on('zoom', () => {
      zoomG.attr('transform', d3.event.transform);
    }));
     
    d3.json('data.json')
      .then(data => {
     
      const root = d3.hierarchy(data);
       root.x0 = height / 2;
       root.y0 = 0;
        const links = treeLayout(root).links();
        const linkPathGenerator = d3.linkVertical() 
          .x(d => d.x)
          .y(d => d.y);
      
      
       
        let groupEnter=g.selectAll('g.resourcebox')
        .data(root.descendants())
        .enter()
        .append('g')
        .attr("transform", function(d) { 
            return "translate(" + (d.x - (nw/2))+ "," + (d.y-(nh/2) )+ ")"; 
          }); 
      
        let box=groupEnter.append('rect')
        .classed("rects", true)
        .attr('x', 1)
        .attr('y',1)
        .attr('width', nw)
        .attr('height', nh)
        .attr("fill", "white")
        .attr('stroke', "darkgray")
        .attr('stroke-width', 1);
        
      groupEnter.append("text")
          .attr("x", function(d) { 
              return 10 })
           .text(function(d) { return d.data.name; })
         .attr("y",(d)=> nh-10);
      
       g.selectAll('g.nodes')
      .data(root.descendants())
      .enter()
      .append('circle')
      .classed('node', true)
      .attr('cx', function(d) {return d.x;})
      .attr('cy', function(d) {return d.y-(nh/2);})
      .attr('r', 10)
      .attr("fill", "lightblue")
      .attr('stroke', "darkgray")
      .attr('stroke-width', 1);
     
        g.selectAll('path').data(links)
          .enter().append('path')
            .attr('d', (d)=>{
          
            return linkPathGenerator(getNewSourceAndTarget(d));
        });
     
     
      });
     
        function getNewSourceAndTarget({source,target}){
        return {source: {x: source.x, y: source.y+(nh/2)}, target: {x: target.x, y: target.y-(nh/2)}};
        }
  
  }(d3));
  
  